@@ -2,10 +2,7 @@
 //
 // A utility for copying SoundPanel assignments between databases.
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: panel_copy.h,v 1.5 2010/07/29 19:32:32 cvs Exp $
-//      $Date: 2010/07/29 19:32:32 $
+//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -36,11 +33,11 @@ class MainObject : public QObject
 {
   Q_OBJECT
  public:
-  MainObject(QObject *parent=0,const char *name=0);
+  MainObject(QObject *parent=0);
 
  private:
-  QSqlDatabase *src_db;
-  QSqlDatabase *dest_db;
+  QSqlDatabase src_db;
+  QSqlDatabase dest_db;
   RDConfig *rd_config;
 };
 
