@@ -2,10 +2,7 @@
 //
 // An RDCatch event copier.
 //
-//   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdcatch_copy.h,v 1.4 2007-02-14 21:48:41 fredg Exp $
-//      $Date: 2007-02-14 21:48:41 $
+//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -40,11 +37,11 @@ class MainObject : public QObject
 {
   Q_OBJECT
  public:
-  MainObject(QObject *parent=0,const char *name=0);
+  MainObject(QObject *parent=0);
 
  private:
-  QSqlDatabase *src_db;
-  QSqlDatabase *dest_db;
+  QSqlDatabase src_db;
+  QSqlDatabase dest_db;
   RDConfig *rd_config;
 };
 
