@@ -805,6 +805,78 @@
         <source>Results Report</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>MARKER</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TRACK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LOG CHAIN</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>LINK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[cart not found]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[music link]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[traffic link]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>whitespace is not permitted in service names</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>new profile</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>[none]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must supply a &quot;from&quot; address</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unable to start sendmail</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sendmail crashed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>sendmail returned non-zero exit code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ok</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>address</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is invalid</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Original RadioTraffic.com Traffic Reconciliation (DEPRECATED)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAddCart</name>
@@ -946,6 +1018,86 @@
         <source>Rivendell service is not active.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ok</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>prior instance already running</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unable to open database</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unable to start a service component</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unknown/invalid command option</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unable to overwrite output [-P given]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>no such service</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>no such log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>no such report</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>log generation failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>schedule import failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>insufficient permissions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>report generation failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>one or more audio imports failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unknown dropbox id</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>no such group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>invalid cart number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>no such scheduler code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>bad ticket</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RDAudioSettingsDialog</name>
@@ -1792,23 +1944,23 @@ Skriv over?</translation>
     <name>RDExportSettingsDialog</name>
     <message>
         <source>Edit Export Settings</source>
-        <translation>Rediger eksportinnstillingar</translation>
+        <translation type="obsolete">Rediger eksportinnstillingar</translation>
     </message>
     <message>
         <source>&amp;Channels:</source>
-        <translation>&amp;Kanalar:</translation>
+        <translation type="obsolete">&amp;Kanalar:</translation>
     </message>
     <message>
         <source>&amp;Sample Rate:</source>
-        <translation>&amp;Punktprøverate:</translation>
+        <translation type="obsolete">&amp;Punktprøverate:</translation>
     </message>
     <message>
         <source>&amp;Bitrate:</source>
-        <translation>&amp;Bitrate:</translation>
+        <translation type="obsolete">&amp;Bitrate:</translation>
     </message>
     <message>
         <source>&amp;Quality:</source>
-        <translation>&amp;Kvalitet:</translation>
+        <translation type="obsolete">&amp;Kvalitet:</translation>
     </message>
     <message>
         <source>&amp;OK</source>
@@ -1938,6 +2090,58 @@ Skriv over?</translation>
         <source>PCM24</source>
         <translation type="unfinished">PCM24</translation>
     </message>
+    <message>
+        <source>Edit Audio Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Format</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channels</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sample Rate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bitrate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Quality</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Duplicate Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>is already in use.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Normalization Level</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Autotrim Level</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>dBFS</source>
+        <translation type="unfinished">dBFS</translation>
+    </message>
 </context>
 <context>
     <name>RDGetAth</name>
@@ -2000,6 +2204,13 @@ for rapportperioden.
         <translation>Pin-nummer:</translation>
     </message>
 </context>
+<context>
+    <name>RDImagePickerModel</name>
+    <message>
+        <source>Image</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>RDImportAudio</name>
     <message>
@@ -2799,7 +3010,7 @@ prøv ein gong til!</translation>
     </message>
     <message>
         <source>[unknown cart]</source>
-        <translation>[ukjend korg]</translation>
+        <translation type="obsolete">[ukjend korg]</translation>
     </message>
     <message>
         <source>Autofill Errors
@@ -2820,5 +3031,57 @@ prøv ein gong til!</translation>
         <source>Import failed</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>invalid start time and/or length on inline traffic break.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>multiple inline traffic breaks not permitted within the same music event</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>In event</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>invalid start time and/or length on track marker.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unexpected event type</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>invalid start time and/or length on note cart.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Note Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Track</source>
+        <translation type="unfinished">Spor</translation>
+    </message>
+    <message>
+        <source>Traffic Link</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unexpected event</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy of</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import file</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
