@@ -4,8 +4,6 @@
 //
 //   (C) Copyright 1996-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//    $Id: rdconf.h,v 1.10.6.3 2013/12/03 23:34:34 cvs Exp $
-//
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU Library General Public License 
 //   version 2 as published by the Free Software Foundation.
@@ -26,17 +24,19 @@
 #define MAX_RETRIES 10
 #include <stdlib.h>
 #include <stdio.h>
+#include <sys/types.h>
 
-#include <qstring.h>
+#include <qcolor.h>
 #include <qdatetime.h>
 #include <qfont.h>
 #include <qhostaddress.h>
+#include <qlist.h>
+#include <qstring.h>
+#include <qstringlist.h>
 #include <qsqldatabase.h>
 #include <qvariant.h>
-#include <qdatetime.h>
-#include <qcolor.h>
-#include <qstringlist.h>
-#include <qcstring.h>
+
+#include <q3cstring.h>
 
 /* Function Prototypes */
 int GetPrivateProfileBool(const char *,const char *,const char *,bool);
@@ -74,14 +74,9 @@ bool RDDoesRowExist(const QString &table,const QString &name,unsigned test,
 		    QSqlDatabase *db=0);
 QVariant RDGetSqlValue(const QString &table,const QString &name,
 		       const QString &test,const QString &param,
-		       QSqlDatabase *db=0,bool *valid=0);
+		       bool *valid=0);
 QVariant RDGetSqlValue(const QString &table,const QString &name,unsigned test,
-		       const QString &param,QSqlDatabase *db=0,bool *valid=0);
-QVariant RDGetSqlValue(const QString &table,
-		       const QString &name1,const QString &test1,
-		       const QString &name2,const QString &test2,
-		       const QString &name3,const QString &test3,
-		       const QString &param,QSqlDatabase *db=0,bool *valid=0);
+		       const QString &param,bool *valid=0);
 bool RDIsSqlNull(const QString &table,const QString &name,
 		 const QString &test,const QString &param,QSqlDatabase *db=0);
 bool RDIsSqlNull(const QString &table,const QString &name,unsigned test,
@@ -89,13 +84,14 @@ bool RDIsSqlNull(const QString &table,const QString &name,unsigned test,
 QString RDGetTimeLength(int mseconds,bool leadzero=false,bool tenths=true);
 int RDSetTimeLength(const QString &string);
 bool RDCopy(const QString &srcfile,const QString &destfile);
-#ifndef WIN32
+bool RDCopy(const QString &srcfile,int dest_fd);
+bool RDCopy(int src_fd,const QString &destfile);
+bool RDCopy(int src_fd,int dest_fd);
 bool RDWritePid(const QString &dirname,const QString &filename,int owner=-1,
 		int group=-1);
 void RDDeletePid(const QString &dirname,const QString &filename);
 bool RDCheckPid(const QString &dirname,const QString &filename);
 pid_t RDGetPid(const QString &pidfile);
-#endif  // WIN32
 QString RDGetHomeDir(bool *found=0);
 bool RDTimeSynced();
 QString RDTruncateAfterWord(QString str,int word,bool add_dots=false);
@@ -108,11 +104,13 @@ QDateTime RDLocalToUtc(const QDateTime &localdatetime);
 QTime RDLocalToUtc(const QTime &localtime);
 QDateTime RDUtcToLocal(const QDateTime &gmtdatetime);
 QTime RDUtcToLocal(const QTime &gmttime);
-int RDTimeZoneOffset();
+//int RDTimeZoneOffset();
 QColor RDGetTextColor(const QColor &background_color);
 bool RDProcessActive(const QString &cmd);
 bool RDProcessActive(const QStringList &cmds);
 bool RDModulesActive();
 QByteArray RDStringToData(const QString &str);
+QString RDStringToHex(const QString &str);
+QList<pid_t> RDGetPids(const QString &program);
 
 #endif   // RDCONF_H
