@@ -2,7 +2,7 @@
 //
 // Abstract Rivendell Log Events
 //
-//   (C) Copyright 2002-2003,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2020 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -72,8 +72,7 @@ class RDLogEvent
    QString xml() const;
 
   private:
-   //   int LoadLines(const QString &log_table,int id_offset,bool track_ptrs);
-   int LoadLines(int id_offset,bool track_ptrs);
+   int LoadLines(const QString &logname,int id_offset,bool track_ptrs);
    void SaveLine(int line);
    void InsertLines(QString values);
    void InsertLineValues(QString *query, int line);
