@@ -2,7 +2,7 @@
 //
 // Scheduler code editor dialog
 //
-//  (C) Copyright 2014,2016 Fred Gleason <fredg@paravelsystems.com>
+//  (C) Copyright 2014-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   Based on original code by Stefan Gabriel <stg@st-gabriel.de>
 //
@@ -23,33 +23,21 @@
 #include <qpainter.h>
 #include <qmessagebox.h>
 
-#include <rddb.h>
+#include "rddb.h"
 #include "rdschedcodes_dialog.h"
 
 RDSchedCodesDialog::RDSchedCodesDialog(QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
-  setCaption(tr("Select Scheduler Codes"));
-
-  //
-  // Create Fonts
-  //
-  QFont font("Helvetica",11,QFont::Bold);
-  font.setPixelSize(11);
-
-  QFont listfont("Helvetica",11);
-  font.setPixelSize(11);
-
+  setWindowTitle(tr("Select Scheduler Codes"));
 
   //
   // Services Selector
   //
   codes_sel=new RDListSelector(this);
-  codes_sel->setFont(listfont);
   codes_sel->sourceSetLabel(tr("Available Codes"));
 
   remove_codes_sel=new RDListSelector(this);
-  remove_codes_sel->setFont(listfont);
   remove_codes_sel->sourceSetLabel(tr("Available Codes"));
   remove_codes_sel->destSetLabel(tr("REMOVE from Carts"));
   
@@ -58,14 +46,14 @@ RDSchedCodesDialog::RDSchedCodesDialog(QWidget *parent)
   //
   edit_ok_button=new QPushButton(tr("&OK"),this);
   edit_ok_button->setDefault(true);
-  edit_ok_button->setFont(font);
+  edit_ok_button->setFont(buttonFont());
   connect(edit_ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
   //
   //  Cancel Button
   //
   edit_cancel_button=new QPushButton(tr("&Cancel"),this);
-  edit_cancel_button->setFont(font);
+  edit_cancel_button->setFont(buttonFont());
   connect(edit_cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 }
 
@@ -122,11 +110,11 @@ int RDSchedCodesDialog::exec(QStringList *sched_codes,QStringList *remove_codes)
     remove_codes_sel->show();
   }
 
-  for(unsigned i=0;i<edit_sched_codes->size();i++) {
+  for(int i=0;i<edit_sched_codes->size();i++) {
     codes_sel->destInsertItem((*edit_sched_codes)[i]);
   } 
   if(edit_remove_codes!=NULL) {
-    for(unsigned i=0;i<edit_remove_codes->size();i++) {
+    for(int i=0;i<edit_remove_codes->size();i++) {
       remove_codes_sel->destInsertItem((*remove_codes)[i]);
     } 
   }
@@ -152,9 +140,8 @@ int RDSchedCodesDialog::exec(QStringList *sched_codes,QStringList *remove_codes)
 void RDSchedCodesDialog::paintEvent(QPaintEvent *e)
 {
   QPainter *p=new QPainter(this);
-  p->setPen(QColor(black));
-  p->moveTo(sizeHint().width(),10);
-  p->lineTo(sizeHint().width(),210);
+  p->setPen(QColor(Qt::black));
+  p->drawLine(sizeHint().width(),10,sizeHint().width(),210);
   p->end();
 }
 
