@@ -29,9 +29,7 @@
 #include <qhostaddress.h>
 #include <qstringlist.h>
 
-#ifndef WIN32
 #include <rdaudioconvert.h>
-#endif  // WIN32
 
 //
 // Data Structure Sizes
@@ -42,7 +40,6 @@
 //
 // Function Prototypes
 //
-#ifndef WIN32
 extern int RDReadPost(char *,int);
 extern int RDPutPostString(char *,char *,char *,int);
 extern int RDFindPostString(const char *,const char *,char *,int);
@@ -56,10 +53,8 @@ extern int RDDecodeString(char *);
 extern int RDPutPlaintext(char *,int);
 extern int RDPurgePlaintext(char *,int);
 extern void RDCgiError(const char *str,int resp_code=200);
-#ifndef WIN32
 extern void RDXMLResult(const char *str,int resp_code,
 			RDAudioConvert::ErrorCode err=RDAudioConvert::ErrorOk);
-#endif  // WIN32
 extern int RDBufferDiff(char *,int,int,int);
 extern void RDPruneAmp(char *);
 extern int RDEscapeQuotes(const char *src,char *dest,int maxlen);
@@ -70,7 +65,6 @@ extern QString RDAuthenticateSession(long int session_id,
 				     const QHostAddress &addr);
 extern void RDLogoutSession(long int session_id,const QHostAddress &addr);
 extern bool RDParsePost(std::map<QString,QString> *vars);
-#endif  // WIN32
 extern QString RDXmlField(const QString &tag,const QString &value,
 			  const QString &attrs="");
 extern QString RDXmlField(const QString &tag,const char *value,
@@ -83,21 +77,28 @@ extern QString RDXmlField(const QString &tag,const bool value,
 			  const QString &attrs="");
 extern QString RDXmlField(const QString &tag,const QDateTime &value,
 			  const QString &attrs="");
+extern QString RDXmlField(const QString &tag,const QDate &value,
+			  const QString &attrs="");
 extern QString RDXmlField(const QString &tag,const QTime &value,
 			  const QString &attrs="");
 extern QString RDXmlField(const QString &tag);
-extern QString RDXmlDate(const QDate &date);
-extern QString RDXmlTime(const QTime &time);
-extern QString RDXmlDateTime(const QDateTime &datetime);
-extern QString RDXmlTimeZoneSuffix();
 extern QString RDXmlEscape(const QString &str);
 extern QString RDXmlUnescape(const QString &str);
+extern QString RDJsonPadding(int padding);
+extern QString RDJsonNullField(const QString &name,int padding=0,
+			       bool final=false);
+extern QString RDJsonField(const QString &name,bool value,int padding=0,
+			   bool final=false);
+extern QString RDJsonField(const QString &name,int value,int padding=0,
+			   bool final=false);
+extern QString RDJsonField(const QString &name,unsigned value,int padding=0,
+			   bool final=false);
+extern QString RDJsonField(const QString &name,const QString &value,
+			   int padding=0,bool final=false);
+extern QString RDJsonField(const QString &name,const QDateTime &value,
+			   int padding=0,bool final=false);
 extern QString RDUrlEscape(const QString &str);
 extern QString RDUrlUnescape(const QString &str);
-extern QString RDWebDateTime(const QDateTime &datetime);
-extern QDateTime RDGetWebDateTime(const QString &str,bool *ok=NULL);
-extern QDate RDGetWebDate(const QString &str,bool *ok=NULL);
-extern QTime RDGetWebTime(const QString &str,bool *ok=NULL);
-extern int RDGetWebMonth(const QString &str,bool *ok=NULL);
+
 
 #endif  // RDWEB_H
