@@ -329,8 +329,8 @@ MainWidget::MainWidget(RDConfig *c,QWidget *parent)
   //
   // Cart Picker
   //
-  catch_cart_dialog=
-    new RDCartDialog(&catch_filter,&catch_group,&catch_schedcode,this);
+  catch_cart_dialog=new RDCartDialog(&catch_filter,&catch_group,
+				     &catch_schedcode,"RDCatch",this);
 
   //
   // Cart List
