@@ -235,10 +235,6 @@ Do you still want to delete?</source>
         <source>Other:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Apply FreeDB Values to Cart</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Tracks</source>
         <translation type="unfinished"></translation>
@@ -343,14 +339,6 @@ Rip</source>
         <source>[none]</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Ripper Error</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unable to create temporary directory!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Rip CD</source>
         <translation type="unfinished"></translation>
@@ -360,6 +348,22 @@ Rip</source>
 Track</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Apply</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Values to Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lookup Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DiskGauge</name>
@@ -386,10 +390,6 @@ Track</source>
         <source>Other:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Apply FreeDB Values to Carts</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Tracks</source>
         <translation type="unfinished"></translation>
@@ -523,14 +523,6 @@ Disk</source>
         <source>Rip aborted!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Ripper Error</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unable to create temporary directory!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Track</source>
         <translation type="unfinished"></translation>
@@ -576,6 +568,18 @@ Selection</source>
         <source>Unable to allocate cart in group</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Apply</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Values to Carts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lookup Error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditCart</name>
