@@ -1,4 +1,6 @@
-<!DOCTYPE TS><TS>
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.0">
 <context>
     <name>AudioCart</name>
     <message>
@@ -23,23 +25,23 @@
     </message>
     <message>
         <source>WT</source>
-        <translation>VT</translation>
+        <translation type="obsolete">VT</translation>
     </message>
     <message>
         <source>DESCRIPTION</source>
-        <translation>SKILDRING</translation>
+        <translation type="obsolete">SKILDRING</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>LENGD</translation>
+        <translation type="obsolete">LENGD</translation>
     </message>
     <message>
         <source>LAST PLAYED</source>
-        <translation>SIST SPELT</translation>
+        <translation type="obsolete">SIST SPELT</translation>
     </message>
     <message>
         <source># OF PLAYS</source>
-        <translation>SPELT GGR</translation>
+        <translation type="obsolete">SPELT GGR</translation>
     </message>
     <message>
         <source>ORIGIN</source>
@@ -47,27 +49,27 @@
     </message>
     <message>
         <source>OUTCUE</source>
-        <translation>UTSPOR</translation>
+        <translation type="obsolete">UTSPOR</translation>
     </message>
     <message>
         <source>START DATE</source>
-        <translation>STARTDATO</translation>
+        <translation type="obsolete">STARTDATO</translation>
     </message>
     <message>
         <source>END DATE</source>
-        <translation>SLUTTDATO</translation>
+        <translation type="obsolete">SLUTTDATO</translation>
     </message>
     <message>
         <source>DAYPART START</source>
-        <translation>DAGDEL START</translation>
+        <translation type="obsolete">DAGDEL START</translation>
     </message>
     <message>
         <source>DAYPART END</source>
-        <translation>DAGDEL SLUTT</translation>
+        <translation type="obsolete">DAGDEL SLUTT</translation>
     </message>
     <message>
         <source>NAME</source>
-        <translation>NAMN</translation>
+        <translation type="obsolete">NAMN</translation>
     </message>
     <message>
         <source>Cuts</source>
@@ -215,10 +217,6 @@ Do you still want to delete?</source>
         <source>You must select a single cut!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>ORD</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>SHA1</source>
         <translation type="unfinished"></translation>
@@ -227,18 +225,66 @@ Do you still want to delete?</source>
         <source>not available</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>INGEST</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>SOURCE</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>unknown</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Wt</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Played</source>
+        <translation type="unfinished">Sist spelt</translation>
+    </message>
+    <message>
+        <source># of Plays</source>
+        <translation type="unfinished">Spelt gonger</translation>
+    </message>
+    <message>
+        <source>Source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ingest</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Outcue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End Date</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daypart Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daypart End</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ord</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CdRipper</name>
@@ -256,7 +302,7 @@ Do you still want to delete?</source>
     </message>
     <message>
         <source>Apply FreeDB Values to Cart</source>
-        <translation>Bruk FreeDB-opplysningar på korga</translation>
+        <translation type="obsolete">Bruk FreeDB-opplysningar på korga</translation>
     </message>
     <message>
         <source>Tracks</source>
@@ -387,10 +433,6 @@ Sjå over innstillingane for ripping, og prøv ein gong til.</translation>
 Rip</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Rip Track</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Title:</source>
         <translation type="unfinished"></translation>
@@ -400,11 +442,35 @@ Rip</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Ripper Error</source>
+        <source>Rip CD</source>
+        <translation type="unfinished">Ripp CD</translation>
+    </message>
+    <message>
+        <source>Rip
+Track</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Unable to create temporary directory!</source>
+        <source>Apply</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Values to Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lookup Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>DiskGauge</name>
+    <message>
+        <source>Free</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -428,7 +494,7 @@ Rip</source>
     </message>
     <message>
         <source>Apply FreeDB Values to Carts</source>
-        <translation>Bruk FreeDB-opplysningar på korgene</translation>
+        <translation type="obsolete">Bruk FreeDB-opplysningar på korgene</translation>
     </message>
     <message>
         <source>Tracks</source>
@@ -621,14 +687,6 @@ Disk</source>
         <source>Rip aborted!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Ripper Error</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unable to create temporary directory!</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Track</source>
         <translation type="unfinished"></translation>
@@ -674,6 +732,18 @@ Selection</source>
         <source>Unable to allocate cart in group</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Apply</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Values to Carts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lookup Error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditCart</name>
@@ -866,10 +936,6 @@ Notes</source>
         <source>&amp;Beats per Minute:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Use Event Length for Now &amp;&amp; Next Updates</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>By Specified Order</source>
         <translation type="unfinished"></translation>
@@ -890,12 +956,24 @@ Notes</source>
         <source>Duplicate Cut Order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Edit Carts [multiple]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit Cart</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use RDLogManager Length for PAD Updates</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditMacro</name>
     <message>
         <source>Edit Macro</source>
-        <translation>Rediger makro</translation>
+        <translation type="obsolete">Rediger makro</translation>
     </message>
     <message>
         <source>&amp;OK</source>
@@ -956,31 +1034,27 @@ Notes</source>
     <name>Filter</name>
     <message>
         <source>Library Filter</source>
-        <translation>Bibliotekfilter</translation>
+        <translation type="obsolete">Bibliotekfilter</translation>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;OK</translation>
+        <translation type="obsolete">&amp;OK</translation>
     </message>
     <message>
         <source>C&amp;lear</source>
-        <translation>&amp;Tøm</translation>
+        <translation type="obsolete">&amp;Tøm</translation>
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation>&amp;Avbryt</translation>
+        <translation type="obsolete">&amp;Avbryt</translation>
     </message>
     <message>
         <source>&amp;Filter:</source>
-        <translation>&amp;Filter:</translation>
+        <translation type="obsolete">&amp;Filter:</translation>
     </message>
 </context>
 <context>
     <name>ListReports</name>
-    <message>
-        <source>RDLibrary Reports</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cart Report</source>
         <translation type="unfinished"></translation>
@@ -1005,10 +1079,6 @@ Notes</source>
         <source>ALL</source>
         <translation type="unfinished">ALT</translation>
     </message>
-    <message>
-        <source>Cart Data Dump (fixed width)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cart Data Dump (CSV)</source>
         <translation type="unfinished"></translation>
@@ -1017,6 +1087,10 @@ Notes</source>
         <source>Prepend Field Names</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Select Report</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MacroCart</name>
@@ -1038,11 +1112,11 @@ Notes</source>
     </message>
     <message>
         <source>LINE</source>
-        <translation>LINE</translation>
+        <translation type="obsolete">LINE</translation>
     </message>
     <message>
         <source>COMMAND</source>
-        <translation>KOMMANDO</translation>
+        <translation type="obsolete">KOMMANDO</translation>
     </message>
     <message>
         <source>Macros</source>
@@ -1066,7 +1140,19 @@ korg</translation>
     </message>
     <message>
         <source>--- End of cart ---</source>
-        <translation>--- Slutten på korga ---</translation>
+        <translation type="obsolete">--- Slutten på korga ---</translation>
+    </message>
+    <message>
+        <source>Line</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Command</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>--- End of Cart ---</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1077,11 +1163,11 @@ korg</translation>
     </message>
     <message>
         <source>rdlibrary : </source>
-        <translation>rdlibrary : </translation>
+        <translation type="obsolete">rdlibrary : </translation>
     </message>
     <message>
         <source>Can&apos;t Connect</source>
-        <translation>Greier ikkje kopla til</translation>
+        <translation type="obsolete">Greier ikkje kopla til</translation>
     </message>
     <message>
         <source>Filter:</source>
@@ -1113,51 +1199,51 @@ korg</translation>
     </message>
     <message>
         <source>CART</source>
-        <translation>KORG</translation>
+        <translation type="obsolete">KORG</translation>
     </message>
     <message>
         <source>GROUP</source>
-        <translation>GRUPPE</translation>
+        <translation type="obsolete">GRUPPE</translation>
     </message>
     <message>
         <source>LENGTH</source>
-        <translation>LENGD</translation>
+        <translation type="obsolete">LENGD</translation>
     </message>
     <message>
         <source>TITLE</source>
-        <translation>TITTEL</translation>
+        <translation type="obsolete">TITTEL</translation>
     </message>
     <message>
         <source>ARTIST</source>
-        <translation>ARTIST</translation>
+        <translation type="obsolete">ARTIST</translation>
     </message>
     <message>
         <source>START</source>
-        <translation>START</translation>
+        <translation type="obsolete">START</translation>
     </message>
     <message>
         <source>END</source>
-        <translation>SLUTT</translation>
+        <translation type="obsolete">SLUTT</translation>
     </message>
     <message>
         <source>CLIENT</source>
-        <translation>KLIENT</translation>
+        <translation type="obsolete">KLIENT</translation>
     </message>
     <message>
         <source>AGENCY</source>
-        <translation>AGENT</translation>
+        <translation type="obsolete">AGENT</translation>
     </message>
     <message>
         <source>USER DEFINED</source>
-        <translation>BRUKARDEFINERT</translation>
+        <translation type="obsolete">BRUKARDEFINERT</translation>
     </message>
     <message>
         <source>CUTS</source>
-        <translation>KUTT</translation>
+        <translation type="obsolete">KUTT</translation>
     </message>
     <message>
         <source>LAST CUT PLAYED</source>
-        <translation>SISTE KUTT SPELT</translation>
+        <translation type="obsolete">SISTE KUTT SPELT</translation>
     </message>
     <message>
         <source>PLAY ORDER</source>
@@ -1165,19 +1251,19 @@ korg</translation>
     </message>
     <message>
         <source>ENFORCE LENGTH</source>
-        <translation>TVING LENGD</translation>
+        <translation type="obsolete">TVING LENGD</translation>
     </message>
     <message>
         <source>PRESERVE PITCH</source>
-        <translation>HALD TONEHØGD</translation>
+        <translation type="obsolete">HALD TONEHØGD</translation>
     </message>
     <message>
         <source>LENGTH DEVIATION</source>
-        <translation>LENGD-FRÅVIK</translation>
+        <translation type="obsolete">LENGD-FRÅVIK</translation>
     </message>
     <message>
         <source>OWNED BY</source>
-        <translation>ÅTT AV</translation>
+        <translation type="obsolete">ÅTT AV</translation>
     </message>
     <message>
         <source>&amp;Add</source>
@@ -1233,9 +1319,9 @@ Vil du sletta ho likevel?</translation>
     </message>
     <message>
         <source>Deleting cart %06u will also empty the clipboard.
-      <byte value="x9"/>Do you still want to proceed?</source>
+      	Do you still want to proceed?</source>
         <translation>Viss du slettar korga %06u, tømer du utklyppstavla.
-      <byte value="x9"/>Vil du halda fram?</translation>
+      	Vil du halda fram?</translation>
     </message>
     <message>
         <source>Empty Clipboard</source>
@@ -1289,18 +1375,6 @@ Vil du sletta ho likevel?</translation>
         <source>User</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>COMPOSER</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>CONDUCTOR</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>PUBLISHER</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Allow Cart Dragging</source>
         <translation type="unfinished"></translation>
@@ -1310,15 +1384,112 @@ Vil du sletta ho likevel?</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Unknown command-line option</source>
+        <source>Unknown command option</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ALBUM</source>
+        <source>Cart</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>LABEL</source>
+        <source>Group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>End</source>
+        <translation type="unfinished">Slutt</translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Label</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Composer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Conductor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Publisher</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Client</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Agency</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User Defined</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cuts</source>
+        <translation type="unfinished">Kutt</translation>
+    </message>
+    <message>
+        <source>Last Cut Played</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enforce Length</source>
+        <translation type="unfinished">Tving lengd</translation>
+    </message>
+    <message>
+        <source>Preserve Pitch</source>
+        <translation type="unfinished">Hald tonehøgd</translation>
+    </message>
+    <message>
+        <source>Length Deviation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Owned By</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Talk</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Run
+&amp;Macro</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>And Scheduler Code:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Matching Carts:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1326,7 +1497,7 @@ Vil du sletta ho likevel?</translation>
     <name>RecordCut</name>
     <message>
         <source>RDLibrary - Record</source>
-        <translation>RDLibrary - Opptak</translation>
+        <translation type="obsolete">RDLibrary - Opptak</translation>
     </message>
     <message>
         <source>&amp;Description</source>
@@ -1574,5 +1745,9 @@ Vil du lagra likevel?</translation>
         <source>Source</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Cut Info / Record</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
