@@ -828,6 +828,18 @@ som er skrudd av for denne tenesta!</translation>
         <source>Reports</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Log Listing (CSV)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Traffic Import</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music Import</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWidget</name>
