@@ -816,6 +816,18 @@ Ação se Evento anterior estiver sendo executado</translation>
         <source>Reports</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Log Listing (CSV)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Traffic Import</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music Import</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWidget</name>
