@@ -2,7 +2,7 @@
 //
 // Edit A Rivendell Log Grid
 //
-//   (C) Copyright 2002-2015 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,18 +21,13 @@
 #ifndef EDIT_GRID_H
 #define EDIT_GRID_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
-#include <qlabel.h>
-#include <qpopupmenu.h>
+#include <qgroupbox.h>
+#include <q3popupmenu.h>
 
+#include <rddialog.h>
 #include <rdpushbutton.h>
 
-#include <rdlistview.h>
-#include <rdclock.h>
-
-
-class EditGrid : public QDialog
+class EditGrid : public RDDialog
 {
  Q_OBJECT
  public:
@@ -59,10 +54,11 @@ class EditGrid : public QDialog
   QString GetClock(int dayofweek,int hour);
   QString edit_servicename;
   QString current_clockname;
+  QGroupBox *edit_day_boxes[7];
   RDPushButton *edit_hour_button[7][24];
-  QPopupMenu *edit_right_menu;
+  Q3PopupMenu *edit_right_menu;
   int edit_rightclick_id;
 };
 
 
-#endif
+#endif  // EDIT_GRID_H
