@@ -2,7 +2,7 @@
 //
 // List Rivendell Log Grids
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,16 +21,11 @@
 #ifndef LIST_GRIDS_H
 #define LIST_GRIDS_H
 
-#include <qdialog.h>
-#include <qsqldatabase.h>
-#include <qlabel.h>
-#include <qpushbutton.h>
-#include <qlistview.h>
+#include <q3listview.h>
 
-#include <rduser.h>
-#include <rdmatrix.h>
+#include <rddialog.h>
 
-class ListGrids : public QDialog
+class ListGrids : public RDDialog
 {
  Q_OBJECT
  public:
@@ -40,12 +35,12 @@ class ListGrids : public QDialog
 
  private slots:
   void editData();
-  void doubleClickedData(QListViewItem *,const QPoint &,int);
+  void doubleClickedData(Q3ListViewItem *,const QPoint &,int);
   void closeData();
 
  private:
   void RefreshList();
-  QListView *edit_grids_list;
+  Q3ListView *edit_grids_list;
 };
 
 
