@@ -2,7 +2,7 @@
 //
 // List Rivendell Services and Report Ages
 //
-//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,55 +18,43 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qmessagebox.h>
-#include <qdatetime.h>
+#include <rdescape_string.h>
 
-#include <rdlog.h>
-#include <rddb.h>
-#include <list_svcs.h>
-#include <svc_rec_dialog.h>
-#include <pick_report_dates.h>
-#include <globals.h>
+#include "globals.h"
+#include "list_svcs.h"
+#include "svc_rec_dialog.h"
+#include "pick_report_dates.h"
 
 ListSvcs::ListSvcs(QWidget *parent)
-  : QDialog(parent,"",true)
+  : RDDialog(parent)
 {
-  setCaption(tr("Rivendell Services"));
+  setWindowTitle("RDLogManager - "+tr("Rivendell Services"));
 
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-
-  //
-  // Create Fonts
-  //
-  QFont bold_font=QFont("Helvetica",12,QFont::Bold);
-  bold_font.setPixelSize(12);
-  QFont font=QFont("Helvetica",12,QFont::Normal);
-  font.setPixelSize(12);
+  setMinimumSize(sizeHint());
 
   //
   // Log List
   //
-  list_log_list=new QListView(this);
+  list_log_list=new Q3ListView(this);
   list_log_list->setAllColumnsShowFocus(true);
   list_log_list->setItemMargin(5);
-  list_log_list->addColumn(tr("SERVICE"));
+  list_log_list->addColumn(tr("Service"));
   list_log_list->setColumnAlignment(0,Qt::AlignLeft);
-  list_log_list->addColumn(tr("OLDEST REPORT"));
+  list_log_list->addColumn(tr("Oldest Report"));
   list_log_list->setColumnAlignment(1,Qt::AlignCenter);
   connect(list_log_list,
-	  SIGNAL(doubleClicked(QListViewItem *,const QPoint &,int)),
+	  SIGNAL(doubleClicked(Q3ListViewItem *,const QPoint &,int)),
 	  this,
-	  SLOT(listDoubleClickedData(QListViewItem *,const QPoint &,int)));
+	  SLOT(listDoubleClickedData(Q3ListViewItem *,const QPoint &,int)));
 
   //
   //  Generate Report Button
   //
   list_generate_button=new QPushButton(this);
-  list_generate_button->setFont(bold_font);
+  list_generate_button->setFont(buttonFont());
   list_generate_button->setText(tr("&Generate\nReports"));
   connect(list_generate_button,SIGNAL(clicked()),this,SLOT(generateData()));
 
@@ -74,7 +62,7 @@ ListSvcs::ListSvcs(QWidget *parent)
   //  Purge Button
   //
   list_purge_button=new QPushButton(this);
-  list_purge_button->setFont(bold_font);
+  list_purge_button->setFont(buttonFont());
   list_purge_button->setText(tr("&Purge\nData"));
   connect(list_purge_button,SIGNAL(clicked()),this,SLOT(purgeData()));
 
@@ -83,7 +71,7 @@ ListSvcs::ListSvcs(QWidget *parent)
   //
   list_close_button=new QPushButton(this);
   list_close_button->setDefault(true);
-  list_close_button->setFont(bold_font);
+  list_close_button->setFont(buttonFont());
   list_close_button->setText(tr("C&lose"));
   connect(list_close_button,SIGNAL(clicked()),this,SLOT(closeData()));
 
@@ -105,7 +93,7 @@ QSizePolicy ListSvcs::sizePolicy() const
 
 void ListSvcs::generateData()
 {
-  QListViewItem *item=list_log_list->selectedItem();
+  Q3ListViewItem *item=list_log_list->selectedItem();
   if(item==NULL) {
     return;
   }
@@ -117,7 +105,7 @@ void ListSvcs::generateData()
 
 void ListSvcs::purgeData()
 {
-  QListViewItem *item=list_log_list->selectedItem();
+  Q3ListViewItem *item=list_log_list->selectedItem();
   if(item==NULL) {
     return;
   }
@@ -128,7 +116,7 @@ void ListSvcs::purgeData()
 }
 
 
-void ListSvcs::listDoubleClickedData(QListViewItem *item,const QPoint &pt,
+void ListSvcs::listDoubleClickedData(Q3ListViewItem *item,const QPoint &pt,
 				     int c)
 {
   generateData();
@@ -153,19 +141,17 @@ void ListSvcs::resizeEvent(QResizeEvent *e)
 void ListSvcs::RefreshList()
 {
   RDSqlQuery *q1;
-  QString tablename;
-  QListViewItem *item;
+  Q3ListViewItem *item;
   list_log_list->clear();
   QString sql="select NAME from SERVICES order by NAME";
 
   RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
-    item=new QListViewItem(list_log_list);
+    item=new Q3ListViewItem(list_log_list);
     item->setText(0,q->value(0).toString());
-    tablename=q->value(0).toString();
-    tablename.replace(" ","_");
-    sql=QString().sprintf("select EVENT_DATETIME from `%s_SRT` \
-                           order by EVENT_DATETIME",(const char *)tablename);
+    sql=QString("select EVENT_DATETIME from ELR_LINES where ")+
+      "SERVICE_NAME=\""+RDEscapeString(q->value(0).toString())+"\" "+
+      "order by EVENT_DATETIME";
     q1=new RDSqlQuery(sql);
     if(q1->first()) {
       item->setText(1,q1->value(0).toDate().toString("MM/dd/yyyy"));
@@ -179,14 +165,13 @@ void ListSvcs::RefreshList()
 }
 
 
-void ListSvcs::RefreshLine(QListViewItem *item)
+void ListSvcs::RefreshLine(Q3ListViewItem *item)
 {
   QString sql;
   RDSqlQuery *q;
-  QString tablename=item->text(0);
-    tablename.replace(" ","_");
-    sql=QString().sprintf("select EVENT_DATETIME from `%s_SRT` \
-                           order by EVENT_DATETIME",(const char *)tablename);
+    sql=QString("select EVENT_DATETIME from ELR_LINES where ")+
+      "SERVICE_NAME=\""+RDEscapeString(item->text(0))+"\" "+
+      "order by EVENT_DATETIME";
     q=new RDSqlQuery(sql);
     if(q->first()) {
       item->setText(1,q->value(0).toDate().toString("MM/dd/yyyy"));
