@@ -1014,14 +1014,6 @@ removerá estos datos.  ¿Remezclar?</translation>
         <source>Unable to clear music links</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Unable to link music log</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Unable to link traffic log</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Generate Log</source>
         <translation type="unfinished"></translation>
@@ -1066,6 +1058,18 @@ removerá estos datos.  ¿Remezclar?</translation>
         <source>No broken rules or validation exceptions found.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>RDLogManager Error Report</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Music schedule import failed!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Traffic schedule import failed!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImportListView</name>
