@@ -2,7 +2,7 @@
 //
 // A Calendar Widget.
 //
-//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,17 +21,13 @@
 #ifndef SVC_REC_H
 #define SVC_REC_H
 
-#include <qwidget.h>
-#include <qsize.h>
-#include <qsizepolicy.h>
-#include <qpushbutton.h>
-#include <qcolor.h>
-#include <qstring.h>
+#include <qcombobox.h>
 #include <qdatetime.h>
 #include <qlabel.h>
-#include <qcombobox.h>
 #include <qspinbox.h>
 
+#include <rdwidget.h>
+
 //
 // Display Settings
 //
@@ -40,7 +36,7 @@
 #define SVC_REC_Y_ORIGIN 30
 #define SVC_REC_Y_INTERVAL 20
 
-class SvcRec : public QWidget
+class SvcRec : public RDWidget
 {
   Q_OBJECT
  public:
@@ -75,7 +71,6 @@ class SvcRec : public QWidget
   QSpinBox *pick_year_spin;
   QLabel *pick_date_label[6][7];
   QDate pick_date;
-  QString pick_tablename;
   int pick_low_year;
   int pick_high_year;
   bool pick_active_days[31];
