@@ -2,7 +2,7 @@
 //
 // A Services/Reports Management Dialog.
 //
-//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,25 +31,20 @@
 #include <qsignalmapper.h>
 #include <qfile.h>
 
-#include <rdreport.h>
+#include <rdapplication.h>
 #include <rddatedecode.h>
+#include <rdreport.h>
 
-#include <globals.h>
-#include <svc_rec_dialog.h>
+#include "globals.h"
+#include "svc_rec_dialog.h"
 
 //
 // Global Classes
 //
 SvcRecDialog::SvcRecDialog(const QString &svcname,QWidget *parent)
-  :QDialog(parent,"",true)
+  : RDDialog(parent)
 {
-  QFont font;
-
-  font=QFont("Helvetica",12,QFont::Bold);
-  font.setPixelSize(12);
-
-  setCaption(QString().sprintf("%s %s",(const char *)svcname,
-			       (const char *)tr("Report Data")));
+  setWindowTitle("RDLogManager - "+svcname+" "+tr("Report Data"));
 
   //
   // Datepicker
@@ -67,20 +62,18 @@ SvcRecDialog::SvcRecDialog(const QString &svcname,QWidget *parent)
   date_delete_button=new QPushButton(this);
   date_delete_button->
     setGeometry(10,sizeHint().height()-60,80,50);
-  date_delete_button->setFont(font);
+  date_delete_button->setFont(buttonFont());
   date_delete_button->setText(tr("&Purge\nData"));
   connect(date_delete_button,SIGNAL(clicked()),this,SLOT(deleteData()));
-#ifndef WIN32
-  date_delete_button->setEnabled(rduser->deleteRec()&&
+  date_delete_button->setEnabled(rda->user()->deleteRec()&&
     date_picker->dayActive(date_picker->date().day()));
-#endif  // WIN32
 
   //
   // Close Button
   //
   QPushButton *button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
-  button->setFont(font);\
+  button->setFont(buttonFont());
   button->setText(tr("&Close"));
   button->setDefault(true);
   connect(button,SIGNAL(clicked()),this,SLOT(closeData()));
@@ -107,13 +100,8 @@ QSizePolicy SvcRecDialog::sizePolicy() const
 
 void SvcRecDialog::dateSelectedData(const QDate &,bool active)
 {
-#ifdef WIN32
-  date_delete_button->
-    setEnabled(date_picker->dayActive(date_picker->date().day()));
-#else
-  date_delete_button->setEnabled(rduser->deleteRec()&&
+  date_delete_button->setEnabled(rda->user()->deleteRec()&&
     date_picker->dayActive(date_picker->date().day()));
-#endif  // WIN32
 }
 
 
