@@ -2,7 +2,7 @@
 //
 // A Services/Reports Management Dialog.
 //
-//   (C) Copyright 2002-2005,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,18 +21,11 @@
 #ifndef DELETE_SVC_REC_DIALOG_H
 #define DELETE_SVC_REC_DIALOG_H
 
-#include <qdialog.h>
-#include <qsize.h>
-#include <qsizepolicy.h>
-#include <qpushbutton.h>
-#include <qcolor.h>
-#include <qstring.h>
-#include <qdatetime.h>
-#include <qlabel.h>
+#include <rddialog.h>
 
-#include <svc_rec.h>
+#include "svc_rec.h"
 
-class SvcRecDialog : public QDialog
+class SvcRecDialog : public RDDialog
 {
  Q_OBJECT
  public:
