@@ -2,7 +2,7 @@
 //
 // System Selector for Rivendell
 //
-//   (C) Copyright 2012,2016 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2012-2019 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -18,29 +18,18 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <unistd.h>
-#include <sys/types.h>
-#include <sys/mount.h>
-#include <errno.h>
-
 #include <qapplication.h>
-#include <qwindowsstyle.h>
-#include <qpainter.h>
-#include <qmessagebox.h>
-#include <qlabel.h>
-#include <qtextcodec.h>
-#include <qtranslator.h>
+#include <qdesktopwidget.h>
 #include <qdir.h>
+#include <qmessagebox.h>
+#include <qprocess.h>
+#include <qtranslator.h>
 
-#include <rd.h>
-#include <rdconf.h>
-#include <rdcmd_switch.h>
-#include <rdstatus.h>
 #include <dbversion.h>
+#include <rdpaths.h>
+#include <rdstatus.h>
 
-#include <rdselect.h>
+#include "rdselect.h"
 
 //
 // Icons
@@ -49,8 +38,8 @@
 #include "../icons/greencheckmark.xpm"
 #include "../icons/redx.xpm"
 
-MainWidget::MainWidget(QWidget *parent)
-  :QWidget(parent)
+MainWidget::MainWidget(RDConfig *c,QWidget *parent)
+  : RDWidget(c,parent)
 {
   //
   // Read Command Options
@@ -100,26 +89,14 @@ MainWidget::MainWidget(QWidget *parent)
   //
   // Fix the Window Size
   //
-  setMinimumWidth(sizeHint().width());
-  setMinimumHeight(sizeHint().height());
-
-  //
-  // Generate Fonts
-  //
-  QFont default_font("Helvetica",12,QFont::Normal);
-  default_font.setPixelSize(12);
-  qApp->setFont(default_font);
-  QFont button_font=QFont("Helvetica",12,QFont::Bold);
-  button_font.setPixelSize(12);
-  QFont label_font=QFont("Helvetica",16,QFont::Bold);
-  label_font.setPixelSize(16);
+  setMinimumSize(sizeHint());
 
   //
   // Create And Set Icons
   //
   login_rivendell_map=new QPixmap(rivendell_22x22_xpm);
-  setIcon(*login_rivendell_map);
-  setCaption(tr("RDSelect")+" v"+VERSION);
+  setWindowIcon(*login_rivendell_map);
+  setWindowTitle(QString("RDSelect - v")+VERSION);
   greencheckmark_map=new QPixmap(greencheckmark_xpm);
   redx_map=new QPixmap(redx_xpm);
 
@@ -139,7 +116,7 @@ MainWidget::MainWidget(QWidget *parent)
   config_dir.setFilter(QDir::Files|QDir::Readable);
   config_dir.setNameFilter("*.conf");
   select_filenames=config_dir.entryList();
-  for(unsigned i=0;i<select_filenames.size();i++) {
+  for(int i=0;i<select_filenames.size();i++) {
     select_filenames[i]=
       QString(RD_DEFAULT_RDSELECT_DIR)+"/"+select_filenames[i];
     if(select_filenames[i]==target) {
@@ -155,27 +132,26 @@ MainWidget::MainWidget(QWidget *parent)
   // Current System Label
   //
   select_current_label=new QLabel(this);
-  select_current_label->setFont(label_font);
-  select_current_label->setAlignment(AlignCenter);
+  select_current_label->setFont(progressFont());
+  select_current_label->setAlignment(Qt::AlignCenter);
 
   //
   // Selector Box
   //
-  select_box=new QListBox(this);
-  select_box->setFont(default_font);
-  connect(select_box,SIGNAL(doubleClicked(QListBoxItem *)),
-	  this,SLOT(doubleClickedData(QListBoxItem *)));
+  select_box=new Q3ListBox(this);
+  connect(select_box,SIGNAL(doubleClicked(Q3ListBoxItem *)),
+	  this,SLOT(doubleClickedData(Q3ListBoxItem *)));
   for(unsigned i=0;i<select_configs.size();i++) {
     select_box->insertItem(select_configs[i]->label());
   }
   select_label=new QLabel(select_box,tr("Available Systems"),this);
-  select_label->setFont(button_font);
+  select_label->setFont(labelFont());
 
   //
   // Ok Button
   //
   ok_button=new QPushButton(this);
-  ok_button->setFont(button_font);
+  ok_button->setFont(buttonFont());
   ok_button->setText(tr("Select"));
   connect(ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
@@ -183,7 +159,7 @@ MainWidget::MainWidget(QWidget *parent)
   // Cancel Button
   //
   cancel_button=new QPushButton(this,"cancel_button");
-  cancel_button->setFont(button_font);
+  cancel_button->setFont(buttonFont());
   cancel_button->setText(tr("&Cancel"));
   connect(cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
@@ -194,13 +170,14 @@ MainWidget::MainWidget(QWidget *parent)
   //
   // Check for Root User 
   //
-
+  /*
   setuid(geteuid());  // So the SETUID bit works as expected
   if(getuid()!=0) {
     QMessageBox::information(this,tr("RDSelect"),
 			     tr("Only root can run this utility!"));
     exit(256);
   }
+  */
 }
 
 
@@ -216,7 +193,7 @@ QSizePolicy MainWidget::sizePolicy() const
 }
 
 
-void MainWidget::doubleClickedData(QListBoxItem *item)
+void MainWidget::doubleClickedData(Q3ListBoxItem *item)
 {
   okData();
 }
@@ -224,28 +201,30 @@ void MainWidget::doubleClickedData(QListBoxItem *item)
 
 void MainWidget::okData()
 {
-  if(RDModulesActive()) {
-    QMessageBox::information(this,tr("RDSelect"),
-			tr("One or more Rivendell modules are still open."));
-    return;
-  }
+  QStringList args;
+  QProcess *proc=NULL;
 
-  if(!VerifyShutdown()) {
+  QStringList f0=select_configs[select_box->currentItem()]->filename().
+    split("/",QString::SkipEmptyParts);
+  args.push_back(f0.last());
+  proc=new QProcess(this);
+  proc->start(QString(RD_PREFIX)+"/bin/rdselect_helper",args);
+  proc->waitForFinished();
+  if(proc->exitStatus()!=QProcess::NormalExit) {
+    QMessageBox::critical(this,"RDSelect - "+tr("Error"),
+			  tr("RDSelect helper process crashed!"));
+    delete proc;
     return;
   }
-  if(!Shutdown(select_current_id)) {
-    SetSystem(-1);
-    QMessageBox::warning(this,tr("RDSelect"),
-			 tr("Unable to shutdown current configuration")+
-			 "\n["+strerror(errno)+"].");
+  if(proc->exitCode()!=0) {
+    QMessageBox::critical(this,"RDSelect - "+tr("Error"),
+			  tr("Unable to select configuration:")+"\n"+
+			  RDConfig::rdselectExitCodeText((RDConfig::RDSelectExitCode)proc->exitCode()));
+    delete proc;
     return;
   }
-  if(!Startup(select_box->currentItem())) {
-    SetSystem(-1);
-    QMessageBox::warning(this,tr("RDSelect"),
-			 tr("Unable to start up new configuration"));
-  }
-  SetSystem(select_box->currentItem());
+  delete proc;
+
   exit(0);
 }
 
@@ -266,47 +245,6 @@ void MainWidget::resizeEvent(QResizeEvent *e)
 }
 
 
-bool MainWidget::Shutdown(int id)
-{
-  RDConfig *conf=select_configs[id];
-
-  if(system("/etc/init.d/rivendell stop")!=0) {
-    return false;
-  }
-  system(QString("umount ")+conf->audioRoot());
-
-  return true;
-}
-
-
-bool MainWidget::Startup(int id)
-{
-  RDConfig *conf=select_configs[id];
-
-  if(!conf->audioStoreMountSource().isEmpty()) {
-    QString cmd=QString("mount");
-    if(!conf->audioStoreMountType().isEmpty()) {
-      cmd+=" -t "+conf->audioStoreMountType();
-    }
-    if(!conf->audioStoreMountOptions().isEmpty()) {
-      cmd+=" -o "+conf->audioStoreMountOptions();
-    }
-    cmd+=" "+conf->audioStoreMountSource()+" "+
-      conf->audioRoot();
-    if(system(cmd)!=0) {
-      return false;
-    }
-  }
-  unlink(RD_CONF_FILE);
-  symlink(select_filenames[id],RD_CONF_FILE);
-  if(system("/etc/init.d/rivendell start")!=0) {
-    return false;
-  }
-
-  return true;
-}
-
-
 void MainWidget::SetSystem(int id)
 {
   QString text=tr("None");
@@ -318,12 +256,6 @@ void MainWidget::SetSystem(int id)
 }
 
 
-bool MainWidget::VerifyShutdown() const
-{
-  return true;
-}
-
-
 void MainWidget::SetCurrentItem(int id)
 {
   QPixmap *pix=redx_map;
@@ -347,13 +279,14 @@ void MainWidget::SetCurrentItem(int id)
 
 int main(int argc,char *argv[])
 {
+  QApplication::setStyle(RD_GUI_STYLE);
   QApplication a(argc,argv);
   
   //
   // Load Translations
   //
   QTranslator qt(0);
-  qt.load(QString(QTDIR)+QString("/translations/qt_")+QTextCodec::locale(),
+  qt.load(QString("/usr/share/qt4/translations/qt_")+QTextCodec::locale(),
 	  ".");
   a.installTranslator(&qt);
 
@@ -375,7 +308,9 @@ int main(int argc,char *argv[])
   //
   // Start Event Loop
   //
-  MainWidget *w=new MainWidget();
+  RDConfig *config=new RDConfig();
+  config->load();
+  MainWidget *w=new MainWidget(config);
   a.setMainWidget(w);
   w->show();
   return a.exec();
